Documentation-only module containing the help pages for the CLI tool.
The Args struct contains the top level options. The Action enum contains the top
level subcommands. Beyond that, *Args structs contain options for that level, and
*Action enums contain subcommands below that level. In structs, field names are
generally transformed to options using by being kebab-cased.
For example, caddy::upgrade::UpgradeArgs represents the subcommand:
$ bestool caddy upgradeand its fields:
pub struct UpgradeArgs {
pub version: String,
pub target: Option<String>,
}are transformed into these options:
--version
--targetSometimes more information is contained in the #[clap()] attributes like defaults and
positionals, and these can be seen by clicking the source link at the top right.
Modules
- alertd
- audit_
psql - caddy
- canopy
- context
- Subcommand-handler context: a type-keyed extensions map.
- crypto
- docs
- file
- kopia
- rdp
- self_
update - ssh
- tamanu
Macros
- subcommands
- Wire up a subcommand level.