Module __help

Documentation-only module containing the help pages for the CLI tool.

The Args struct contains the top level options. The Action enum contains the top level subcommands. Beyond that, *Args structs contain options for that level, and *Action enums contain subcommands below that level. In structs, field names are generally transformed to options using by being kebab-cased.

For example, caddy::configure_tamanu::ConfigureTamanuArgs represents the subcommand:

$ bestool caddy configure-tamanu

and its fields:

pub struct ConfigureTamanuArgs {
    pub path: PathBuf,
    pub print: bool,
    pub domain: String,
    pub api_port: NonZeroU16,
    pub api_version: String,
    pub web_version: String,
    pub email: Option<String>,
    pub zerossl_api_key: Option<String>,
}

are transformed into these options:

--path
--print
--domain
--api-port
--api-version
--web-version
--email
--zerossl-api-key

Sometimes more information is contained in the #[clap()] attributes like defaults and positionals, and these can be seen by clicking the source link at the top right.

Modules

caddy
completions
context
crypto
self_update
ssh
tamanu
walg

Macros

subcommands

Structs

Args
BES Tooling
Context

Enums

Action

Functions

run